test-smooth
===========

Test various smoothing operators.

This test checks that `averageY(const Field2D &f)`, `averageY(const Field3D &f)`
and `smooth_y(const Field3D &f)` give the same results as existing benchmarks.
